parse_attributes

Function parse_attributes 

pub fn parse_attributes(
    keys: &[&str],
    attrs: Option<&HashMap<&str, &str>>,
) -> Result<HashMap<String, String>>
Parse an optional key-value &str map for allowed keys, returning a map of owned strings.

Returns an Invalid error if not all keys are allowed.