pub fn parse_attributes(
keys: &[&str],
attrs: Option<&HashMap<&str, &str>>,
) -> Result<HashMap<String, String>>Expand description
Parse an optional key-value &str map for allowed keys, returning a map of owned strings.
Returns an Invalid error if not all keys are allowed.